@@ -88,7 +88,7 @@ create(Context_t *ctx)
 
 
 static void
-cube()
+cube(void)
 {
   glDisable(GL_TEXTURE_2D);
   glColor3f(1, 1, 1);
@@ -132,19 +132,19 @@ cube()
 }
 
 
-static inline void t1()
+static inline void t1(void)
 {
   glTexCoord2f(ZERO, ZERO);
 }
-static inline void t2()
+static inline void t2(void)
 {
   glTexCoord2f(ZERO, ONE);
 }
-static inline void t3()
+static inline void t3(void)
 {
   glTexCoord2f(ONE, ONE);
 }
-static inline void t4()
+static inline void t4(void)
 {
   glTexCoord2f(ONE, ZERO);
 }
