@@ -47,7 +47,7 @@
                                   floor(INIT_INC * CURVE_VOL_STEP) > INIT_INC  */
 
 uint32_t version = 0;
-uint32_t options = BO_GFX|BO_SFX2D|BO_LENS|BO_IMAGE;
+uint32_t options = BO_GFX | BO_SFX | BO_LENS | BO_IMAGE;
 enum LayerMode mode = LM_OVERLAY;
 char desc[] = "Show image scrolling colors on beat";
 char dname[] = "Image colrot beat";
