@@ -21,7 +21,7 @@
 
 
 uint32_t version = 0;
-uint32_t options = BO_MIRROR|BO_HOR;
+uint32_t options = BO_DISPLACE | BO_MIRROR | BO_HOR;
 char dname[] = "Mirror bottom";
 char desc[] = "Mirror effect";
 
