@@ -27,7 +27,7 @@ const char *direction_list[DIRECTION_NB] = { "Downwards", "Upwards", "Bounce" };
 
 
 uint32_t version = 0;
-uint32_t options = BO_GFX|BO_IMAGE;
+uint32_t options = BO_GFX | BO_IMAGE | BO_VER;
 char dname[] = "Scanline Y";
 char desc[] = "Vertical scanline";
 
@@ -37,7 +37,7 @@ on_switch_on(Context_t *ctx)
 {
   direction = DOWNWARDS;
   current_direction = -1;
-  thickness = 1;
+  thickness = b_rand_int32_range(1, 6);
   set_size();
 }
 
