@@ -21,7 +21,7 @@
 
 
 uint32_t version = 0;
-uint32_t options = BO_WARP|BO_LENS;
+uint32_t options = BO_DISPLACE | BO_LENS;
 char desc[] = "Tunnel effect";
 char dname[] = "Tunnel";
 
