@@ -29,45 +29,42 @@
 #define BULFIUS_OPTIONS "OPTIONS"
 #define BULFIUS_STAR    "*"
 
-/*
-#define BULFIUS_COMMAND        "/command"
-#define BULFIUS_COMMAND_FMT    "/:cmd"
-#define BULFIUS_COMMANDS       "/commands"
-#define BULFIUS_FRAME          "/frame"
-#define BULFIUS_PARAMETERS     "/parameters"
-#define BULFIUS_PARAMETERS_FMT "/:plugin"
-#define BULFIUS_SEQUENCE       "/sequence"
-#define BULFIUS_SEQUENCES      "/sequences"
-#define BULFIUS_STATISTICS     "/statistics"
-// Web UI
-#define BULFIUS_UI_COMMAND       "/ui/command"
-#define BULFIUS_UI_ROOT          "/"
-*/
 // Websocket
-#define BULFIUS_UI_WEBSOCKET     "/ui"
-#define BULFIUS_UI_PREVIEW_WS    "/ui/preview"
+#define BULFIUS_WEBSOCKET      "/ui"
+#define BULFIUS_PREVIEW_WS     "/ui/preview"
 // Endpoints
 #define BULFIUS_PLUGINS        "/plugins"
 #define BULFIUS_COLORMAP       "/colormap"
 #define BULFIUS_IMAGE          "/image"
 // Vue UI endpoints
-#define BULFIUS_VUI_FAVICO_URL "/favicon.ico"
-#define BULFIUS_VUI_CSS_ROOT   "/css"
-#define BULFIUS_VUI_IMG_ROOT   "/img"
-#define BULFIUS_VUI_JS_ROOT    "/js"
-#define BULFIUS_VUI_MEDIA_ROOT "/media"
-#define BULFIUS_VUI_DEMOS_ROOT "/sequences"
-#define BULFIUS_VUI_STATIC_FMT ":file"
-#define BULFIUS_VUI_INDEX_FILE "index.html"
-#define BULFIUS_VUI_FAVICO_ICO "favicon.ico"
-#define BULFIUS_VUI_INDEX  1
-#define BULFIUS_VUI_FAVICO 2
-#define BULFIUS_VUI_CSS    3
-#define BULFIUS_VUI_IMG    4
-#define BULFIUS_VUI_JS     5
-#define BULFIUS_VUI_MEDIA  6
-#define BULFIUS_VUI_DEMOS  7
-#define BULFIUS_VUI_SETTINGS   "/settings"
+#define BULFIUS_FAVICO_URL     "/favicon.ico"
+#define BULFIUS_CSS_ROOT       "/css"
+#define BULFIUS_IMG_ROOT       "/img"
+#define BULFIUS_JS_ROOT        "/js"
+#define BULFIUS_MEDIA_ROOT     "/media"
+#define BULFIUS_DEMOS_ROOT     "/sequences"
+#define BULFIUS_STATIC_FMT     ":file"
+#define BULFIUS_INDEX_FILE     "index.html"
+#define BULFIUS_FAVICO_ICO     "favicon.ico"
+#define BULFIUS_SETTINGS       "/settings"
+// REST API
+#define BULFIUS_COMMANDS       "/commands"
+#define BULFIUS_FRAME          "/frame"
+#define BULFIUS_PARAMETERS     "/parameters"
+#define BULFIUS_PARAMETERS_FMT "/:plugin"
+#define BULFIUS_STATISTICS     "/statistics"
+#define BULFIUS_SEQUENCE       "/sequence"
+#define BULFIUS_SEQUENCES      "/sequences"
+#define BULFIUS_COMMAND        "/command"
+#define BULFIUS_COMMAND_FMT    "/:cmd"
+// Vui pages
+#define BULFIUS_INDEX  1
+#define BULFIUS_FAVICO 2
+#define BULFIUS_CSS    3
+#define BULFIUS_IMG    4
+#define BULFIUS_JS     5
+#define BULFIUS_MEDIA  6
+#define BULFIUS_DEMOS  7
 
 // OPTIONS
 int callback_options(const struct _u_request *, struct _u_response *, void *);
