@@ -17,6 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <wand/magick_wand.h>
 #include "bulfius.h"
 #include "context.h"
 
@@ -26,7 +27,7 @@ callback_get_frame(const struct _u_request *request, struct _u_response *respons
 {
   Context_t *ctx = user_data;
   uint8_t *png = NULL;
-  uint32_t png_datalen;
+  size_t png_datalen;
   long width = 0;
   long height = 0;
   const char *w = u_map_get(request->map_url, "w");
@@ -34,8 +35,8 @@ callback_get_frame(const struct _u_request *request, struct _u_response *respons
 
   assert(NULL != ctx);
   if ((NULL != w) && (NULL != h)) {
-    width = xatol(w);
-    height = xatol(h);
+    width = xstrtol(w);
+    height = xstrtol(h);
 
     // maximum rescale to HD
     if ((width > 0) && (height > 0) && (width <= 1920) && (height <= 1080)) {
@@ -46,11 +47,11 @@ callback_get_frame(const struct _u_request *request, struct _u_response *respons
       return U_CALLBACK_COMPLETE;
     }
   } else {
-    Context_to_PNG(ctx, &png, &png_datalen, width, height);
+    Context_to_PNG(ctx, &png, &png_datalen, 0, 0);
   }
   ulfius_set_binary_body_response(response, 200, (const char *)png, png_datalen);
-  xfree(png);
-  u_map_put(response->map_header, "Content-Type", "image/png");
+  MagickRelinquishMemory(png);
+  ulfius_add_header_to_response(response, "Content-Type", "image/png");
 
   return U_CALLBACK_COMPLETE;
 }
