@@ -49,7 +49,7 @@ callback_post_parameters(const struct _u_request *request, struct _u_response *r
 
         if (NULL == body) {
           // error
-          VERBOSE(printf("[!] %s: JSON error: %s\n", __FILE__, jerror.text));
+          fprintf(stderr, "[!] %s: JSON error: %s\n", __FILE__, jerror.text);
           ulfius_set_string_body_response(response, 400, NULL);
         } else {
           // iterate over json post body
@@ -74,7 +74,7 @@ callback_post_parameters(const struct _u_request *request, struct _u_response *r
                 if (json_is_integer(value)) {
                   new_value = value;
                 } else {
-                  new_value = json_integer(xatol(json_string_value(value)));
+                  new_value = json_integer(xstrtol(json_string_value(value)));
                 }
               } else if (json_is_real(old_value)) {
                 if (json_is_real(value)) {
