@@ -109,21 +109,21 @@ callback_vui_get_static(const struct _u_request *request, struct _u_response *re
   char *prefix = "";
 
   assert(NULL != user_data);
-  if (user_data == (void *)BULFIUS_VUI_INDEX) {
-    file = BULFIUS_VUI_INDEX_FILE;
-  } else if (user_data == (void *)BULFIUS_VUI_FAVICO) {
-    file = BULFIUS_VUI_FAVICO_ICO;
+  if (user_data == (void *)BULFIUS_INDEX) {
+    file = BULFIUS_INDEX_FILE;
+  } else if (user_data == (void *)BULFIUS_FAVICO) {
+    file = BULFIUS_FAVICO_ICO;
   } else {
-    if (user_data == (void *)BULFIUS_VUI_CSS) {
-      prefix = BULFIUS_VUI_CSS_ROOT;
-    } else if (user_data == (void *)BULFIUS_VUI_IMG) {
-      prefix = BULFIUS_VUI_IMG_ROOT;
-    } else if (user_data == (void *)BULFIUS_VUI_JS) {
-      prefix = BULFIUS_VUI_JS_ROOT;
-    } else if (user_data == (void *)BULFIUS_VUI_MEDIA) {
-      prefix = BULFIUS_VUI_MEDIA_ROOT;
-    } else if (user_data == (void *)BULFIUS_VUI_DEMOS) {
-      prefix = BULFIUS_VUI_DEMOS_ROOT;
+    if (user_data == (void *)BULFIUS_CSS) {
+      prefix = BULFIUS_CSS_ROOT;
+    } else if (user_data == (void *)BULFIUS_IMG) {
+      prefix = BULFIUS_IMG_ROOT;
+    } else if (user_data == (void *)BULFIUS_JS) {
+      prefix = BULFIUS_JS_ROOT;
+    } else if (user_data == (void *)BULFIUS_MEDIA) {
+      prefix = BULFIUS_MEDIA_ROOT;
+    } else if (user_data == (void *)BULFIUS_DEMOS) {
+      prefix = BULFIUS_DEMOS_ROOT;
     }
     file = u_map_get(request->map_url, "file");
   }
