@@ -94,6 +94,10 @@ Plugin_load(Plugin_t *p)
   p->desc = (char *) dlsym(p->handle, "desc");
   B_GOTSYM(p->desc, "desc");
 
+  /* get HTML description */
+  p->html_description = (char *) dlsym(p->handle, "html_description");
+  B_GOTSYM(p->html_description, "html_description");
+
   p->create = (int8_t (*)(struct Context_s *)) dlsym(p->handle, "create");
   B_DLSYM(p->destroy, "destroy");
   p->check_version = (int8_t (*)(uint32_t)) dlsym(p->handle, "check_version");
