@@ -33,7 +33,7 @@ typedef struct SequenceManager_s {
 } SequenceManager_t;
 
 
-SequenceManager_t *SequenceManager_new();
+SequenceManager_t *SequenceManager_new(void);
 void SequenceManager_delete(SequenceManager_t *);
 
 void SequenceManager_toggle_lens(Sequence_t *);
@@ -51,8 +51,8 @@ void SequenceManager_set_layer_mode(const Sequence_t *, const char *, const enum
 
 json_t *SequenceManager_command(struct Context_s *, const enum Command, const char, const char);
 
-void SequenceManager_lock(SequenceManager_t *);
-void SequenceManager_unlock(SequenceManager_t *);
+int SequenceManager_lock(SequenceManager_t *);
+int SequenceManager_unlock(SequenceManager_t *);
 
 void SequenceManager_reorder(Sequence_t *, const json_t *);
 
