@@ -318,7 +318,7 @@ get_desktop_dir(void)
   FILE *fp;
   char dir[1035];
 
-  fp = popen("/usr/bin/xdg-user-dir DESKTOP", "r");
+  fp = popen("xdg-user-dir DESKTOP", "r");
   if (NULL == fp) {
     fprintf(stderr, "[!] Failed to run xdg-user-dir\n" );
     return NULL;
@@ -367,12 +367,15 @@ create_dirs(void)
     mkdir(d, DIRECTORY_MODE);
     g_free(d);
 
-    gchar *cmd = g_strdup_printf("/bin/ln -sf %s/.%s %s/%s", g_get_home_dir(), PACKAGE_NAME, dir, DESKTOP_DIR);
-    int ret = system(cmd);
+    gchar *target = g_strdup_printf("%s/.%s", g_get_home_dir(), PACKAGE_NAME);
+    gchar *linkpath = g_strdup_printf("%s/%s", dir, DESKTOP_DIR);
+    unlink(linkpath);
+    int ret = symlink(target, linkpath);
     if (ret == -1) {
-      xperror("system");
+      xperror("symlink");
     }
-    g_free(cmd);
+    g_free(target);
+    g_free(linkpath);
 
     d = g_strdup_printf("%s/%s/images", dir, DESKTOP_DIR);
     g_mkdir_with_parents(d, DIRECTORY_MODE);
